.. intro

Introduction
--------------------------------------------------------------------

blah blah blah

.. graphviz::

   digraph g { node [shape=record,height=.08,fontsize=11];     
     boing[label = "[A0]\n8|BBB\n8|CCC\n8|DDD\n8|TIMESTAMP\n16"];
   }
   
Lorem ipsum etc.